==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ApplicationVisibilityHide.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Hides the app for specific end-user apps
 */
@ApiModel(description = "Hides the app for specific end-user apps")
@JsonPropertyOrder({ ApplicationVisibilityHide.JSON_PROPERTY_I_O_S, ApplicationVisibilityHide.JSON_PROPERTY_WEB })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationVisibilityHide implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_I_O_S = "iOS";
    private Boolean iOS = false;

    public static final String JSON_PROPERTY_WEB = "web";
    private Boolean web = false;

    public ApplicationVisibilityHide() {
    }

    public ApplicationVisibilityHide iOS(Boolean iOS) {

        this.iOS = iOS;
        return this;
    }

    /**
     * Okta Mobile for iOS or Android (pre-dates Android)
     *
     * @return iOS
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "false", value = "Okta Mobile for iOS or Android (pre-dates Android)")
    @JsonProperty(JSON_PROPERTY_I_O_S)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getiOS() {
        return iOS;
    }

    @JsonProperty(JSON_PROPERTY_I_O_S)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setiOS(Boolean iOS) {
        this.iOS = iOS;
    }

    public ApplicationVisibilityHide web(Boolean web) {

        this.web = web;
        return this;
    }

    /**
     * Okta End-User Dashboard on a web browser
     *
     * @return web
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "true", value = "Okta End-User Dashboard on a web browser")
    @JsonProperty(JSON_PROPERTY_WEB)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getWeb() {
        return web;
    }

    @JsonProperty(JSON_PROPERTY_WEB)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setWeb(Boolean web) {
        this.web = web;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationVisibilityHide applicationVisibilityHide = (ApplicationVisibilityHide) o;
        return Objects.equals(this.iOS, applicationVisibilityHide.iOS)
                && Objects.equals(this.web, applicationVisibilityHide.web);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(iOS, web);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationVisibilityHide {\n");
        sb.append("    iOS: ").append(toIndentedString(iOS)).append("\n");
        sb.append("    web: ").append(toIndentedString(web)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ApplicationVisibilityHide.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Hides the app for specific end-user apps
 */
@ApiModel(description = "Hides the app for specific end-user apps")
@JsonPropertyOrder({ ApplicationVisibilityHide.JSON_PROPERTY_I_O_S, ApplicationVisibilityHide.JSON_PROPERTY_WEB })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationVisibilityHide implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_I_O_S = "iOS";
    private Boolean iOS = false;

    public static final String JSON_PROPERTY_WEB = "web";
    private Boolean web = false;

    public ApplicationVisibilityHide() {
    }

    public ApplicationVisibilityHide iOS(Boolean iOS) {

        this.iOS = iOS;
        return this;
    }

    /**
     * Okta Mobile for iOS or Android (pre-dates Android)
     *
     * @return iOS
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "false", value = "Okta Mobile for iOS or Android (pre-dates Android)")
    @JsonProperty(JSON_PROPERTY_I_O_S)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getiOS() {
        return iOS;
    }

    @JsonProperty(JSON_PROPERTY_I_O_S)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setiOS(Boolean iOS) {
        this.iOS = iOS;
    }

    public ApplicationVisibilityHide web(Boolean web) {

        this.web = web;
        return this;
    }

    /**
     * Okta End-User Dashboard on a web browser
     *
     * @return web
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "true", value = "Okta End-User Dashboard on a web browser")
    @JsonProperty(JSON_PROPERTY_WEB)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getWeb() {
        return web;
    }

    @JsonProperty(JSON_PROPERTY_WEB)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setWeb(Boolean web) {
        this.web = web;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationVisibilityHide applicationVisibilityHide = (ApplicationVisibilityHide) o;
        return Objects.equals(this.iOS, applicationVisibilityHide.iOS)
                && Objects.equals(this.web, applicationVisibilityHide.web);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(iOS, web);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationVisibilityHide {\n");
        sb.append("    iOS: ").append(toIndentedString(iOS)).append("\n");
        sb.append("    web: ").append(toIndentedString(web)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
